InterruptReader

Struct InterruptReader 

pub struct InterruptReader<R> { /* private fields */ }
An interruptable, buffered Reader.

This reader is created by wrapping a Read struct in the interrupt_read::pair function, which also returns an Interruptor, which is capable of sending interrupt signals, which make any read operations on the InterruptReader return an error of kind ErrorKind::Other, with a payload of InterruptReceived.

When an interrupt is received, the underlying data is not lost, it still exists, and if you call a reading function again, it will be retrieved, unless another interrupt is sent before that.

You can check if an std::io::Error is of this type by calling the is_interrupt function.

Examples

One potential application of this struct is if you want to stop a thread that is reading from the stdout of a child process without necessarily terminating said childrop_:

use std::{
    io::{BufRead, ErrorKind},
    process::{Child, Command, Stdio},
    time::Duration,
};

use interrupt_read::{is_interrupt, pair};

struct ChildKiller(Child);
impl Drop for ChildKiller {
    fn drop(&mut self) {
        _ = self.0.kill();
    }
}

// Prints "hello\n" every second forever.
let mut child = Command::new("bash")
    .args(["-c", r#"while true; do echo "hello"; sleep 1; done"#])
    .stdout(Stdio::piped())
    .spawn()
    .unwrap();

let (mut stdout, interruptor) = pair(child.stdout.take().unwrap());
let _child_killer = ChildKiller(child);

let join_handle = std::thread::spawn(move || {
    let mut string = String::new();
    loop {
        match stdout.read_line(&mut string) {
            Ok(0) => break Ok(string),
            Ok(_) => {}
            Err(err) if is_interrupt(&err) => {
                break Ok(string);
            }
            Err(err) => break Err(err),
        }
    }
});

std::thread::sleep(Duration::new(3, 1_000_000));

interruptor.interrupt()?;

let result = join_handle.join().unwrap()?;

assert_eq!(result, "hello\nhello\nhello\n");

Ok(())

Implementations

Source

impl<R: Read> InterruptReader<R>

pub fn into_inner(self) -> Result<R>

Unwraps this InterruptReader, returning the underlying reader.

Note that any leftover data in the internal buffer is lost. Therefore, a following read from the underlying reader may lead to data loss.

This may return Err if the underlying joined thread has panicked, probably because the Reader has done so.