is_interrupt

Function is_interrupt 

pub fn is_interrupt(err: &Error) -> bool
Wether the error in question originated from an Interruptor calling Interruptor::interrupt.

This just checks if the error is of type InterruptReceived..