pub fn is_interrupt(err: &Error) -> boolExpand description
Wether the error in question originated from an Interruptor
calling Interruptor::interrupt.
This just checks if the error is of type InterruptReceived..
pub fn is_interrupt(err: &Error) -> boolWether the error in question originated from an Interruptor
calling Interruptor::interrupt.
This just checks if the error is of type InterruptReceived..