Interruptor

Struct Interruptor 

pub struct Interruptor(/* private fields */);
An interruptor for an InterruptReader.

This struct serves the purpose of interrupting any of the Read or BufRead functions being performend on the InterruptReader

If it is dropped, the InterruptReader will no longer be able to be interrupted.

Implementations

Source

impl Interruptor

pub fn interrupt(&self) -> Result<(), InterruptSendError>

Interrupts the InterruptReader

This will send an interrupt event to the reader, which makes the next read operation return Err, with an ErrorKind::Other with a payload of InterruptReceived.

You can check if an std::io::Error is of this type by calling the is_interrupt function.

Subsequent read operations proceed as normal.